@@ -231,6 +231,10 @@ based on the filename itself and `jka-compr-compression-info-list'."
       nil)))
 
 
+;; XEmacs change
+(defmacro jka-value-if-bound (symbol)
+  `(if (boundp (quote ,symbol)) ,symbol))
+
 ;; XEmacs change
 (define-error 'compression-error "Compression error" 'file-error)
 
@@ -311,7 +315,11 @@ to keep: LEN chars starting BEG chars from the beginning."
   (if jka-compr-use-shell
 
       (let ((err-file (jka-compr-make-temp-name))
-	    (coding-system-for-read (or coding-system-for-read 'undecided))
+	    (coding-system-for-read (or
+				     ;; XEmacs Change
+				     (jka-value-if-bound
+				           coding-system-for-read) 
+				     'undecided))
 	    (coding-system-for-write 'no-conversion))
 	    
 	(unwind-protect
@@ -530,9 +538,11 @@ There should be no more than seven characters after the final `/'."
 	       (jka-compr-run-real-handler 'file-local-copy (list filename)))
 	      local-file
 	      size start
-	      (coding-system-for-read
-	       (or coding-system-for-read
-		   'undecided)))
+	      (coding-system-for-read	       
+	       (or
+		;; XEmacs change
+		(jka-value-if-bound coding-system-for-read)
+		'undecided)))
 		   ;; XEmacs change; skip multibyte-mode crap
 ;		   (and (null enable-multibyte-characters)
 ;			(or (auto-coding-alist-lookup
@@ -779,10 +789,7 @@ It is not recommended to set this variable permanently to anything but nil.")
 ;;;###autoloadReturns the new status of auto compression (non-nil means on)."
 ;;;###autoload  (interactive "P")
 ;;;###autoload  (if (not (fboundp 'jka-compr-installed-p))
-;;;###autoload      (progn
-;;;###autoload        (require 'jka-compr)
-;;;###autoload        ;; That turned the mode on, so make it initially off.
-;;;###autoload        (toggle-auto-compression)))
+;;;###autoload      (require 'jka-compr))
 ;;;###autoload  (toggle-auto-compression arg t))
 
 ;; XEmacs:  autoload this function
